@@ -1,11 +1,14 @@
 {-# LANGUAGE OverloadedStrings #-}
 
-import Data.GI.CodeGen.CabalHooks (setupHaskellGIBinding)
+import Data.GI.CodeGen.CabalHooks (setupBinding, TaggedOverride(..))
+
+
 
 main :: IO ()
-main = setupHaskellGIBinding name version verbose overridesFile outputDir
+main = setupBinding name version verbose overridesFile inheritedOverrides outputDir
   where name = "cairo"
         version = "1.0"
         overridesFile = Just "cairo.overrides"
         verbose = False
         outputDir = Nothing
+        inheritedOverrides = []
